## [1.2.3] - {}

### Added

* Added support for GMP 20.08 [#254](https://github.com/greenbone/python-gvm/pull/254)

### Changed

* Refactored Gmp classes into mixins [#254](https://github.com/greenbone/python-gvm/pull/254)

### Fixed

* Require method and condition arguments for modify_alert with an event [#267](https://github.com/greenbone/python-gvm/pull/267)

[1.2.3]: https://github.com/greenbone/python-gvm/compare/v1.6.0...hidden1.2.3

